@@ -39,8 +39,10 @@
 #include <libexif/exif-data.h>
 
 #define HOME_DIR g_get_home_dir()
+#define DEFAULT_SINGLE "/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png"
 
-#define _(String) dgettext("hildon-libs", String)
+#define _tran(String) dgettext("hildon-libs", String)
+#define _(String) gettext (String)
 
 #define PERSONAL_PHOTO_FRAME_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE (obj,\
 							                         PERSONAL_TYPE_PHOTO_FRAME,\
@@ -135,7 +137,7 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
 		}
         self->priv->singleFilename = g_key_file_get_string (keyFile, "config", "singleFilename", &error);
         if (error) {
-            self->priv->singleFilename = "/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png";
+            self->priv->singleFilename = DEFAULT_SINGLE;
             g_error_free (error);
             error = NULL;
         }
@@ -180,7 +182,7 @@ void personal_photo_frame_read_settings ( PersonalPhotoFrame *self )
     } else {
 		gchar *string = g_build_path ("/", HOME_DIR, "MyDocs/.images", NULL);
 		self->priv->singleMode = FALSE;
-        self->priv->singleFilename = "/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png";
+        self->priv->singleFilename = DEFAULT_SINGLE;
 		self->priv->slideshowDirname = g_strdup (string);
 		self->priv->slideshowNum = 0;
 		self->priv->slideshowDuration = 3;
@@ -434,7 +436,7 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 			g_dir_close (dir);
 		} else {
 			g_object_unref (self->priv->image);
-			self->priv->image = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png", self->priv->actualSize, self->priv->actualSize, TRUE, NULL);
+			self->priv->image = gdk_pixbuf_new_from_file_at_scale (DEFAULT_SINGLE, self->priv->actualSize, self->priv->actualSize, TRUE, NULL);
 		}
 	}
 }
@@ -443,7 +445,13 @@ void personal_photo_from_single_photo_select (GtkWidget *button, PersonalPhotoFr
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
 	GtkWidget *dialog = hildon_file_chooser_dialog_new (GTK_WINDOW (self->priv->settingsDialog), GTK_FILE_CHOOSER_ACTION_OPEN);
-	gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (dialog), self->priv->singleFilename);
+	if ((!gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (dialog), self->priv->singleFilename)
+		|| (g_ascii_strcasecmp (DEFAULT_SINGLE, self->priv->singleFilename) == 0)))
+	{
+		gchar *folder = g_build_filename (HOME_DIR, "MyDocs", NULL);
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), folder);
+		g_free (folder);
+	}
 	GtkFileFilter *filter = gtk_file_filter_new ();
 	gtk_file_filter_add_mime_type (filter, "image/*");
 	gtk_file_chooser_add_filter (dialog, filter);
@@ -488,8 +496,8 @@ void personal_photo_frame_mode_toggle (GtkToggleButton *toggleButton, PersonalPh
 void personal_photo_frame_settings (HDHomePluginItem *hitem, PersonalPhotoFrame *self)
 {
 	//g_warning("%s", __PRETTY_FUNCTION__);
-	self->priv->settingsDialog = gtk_dialog_new_with_buttons ("Personal Photo Frame Settings",
-        NULL, 0, _("wdgt_bd_save"), GTK_RESPONSE_ACCEPT, NULL);
+	self->priv->settingsDialog = gtk_dialog_new_with_buttons (_("Personal Photo Frame Settings"),
+        NULL, 0, _tran("wdgt_bd_save"), GTK_RESPONSE_ACCEPT, NULL);
     GtkWidget *content_area = gtk_dialog_get_content_area (GTK_DIALOG (self->priv->settingsDialog));
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 	
@@ -497,28 +505,28 @@ void personal_photo_frame_settings (HDHomePluginItem *hitem, PersonalPhotoFrame
 	self->priv->slideshowModeBox = gtk_vbox_new (FALSE, 0);
 	
 	GtkWidget *sizeSelector = hildon_touch_selector_new_text ();
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), "small");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), "medium");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), "large");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), _("small"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), _("medium"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (sizeSelector), _("large"));
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (sizeSelector), 0, self->priv->widgetSize);
 	
 	GtkWidget *widgetSize = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
-	hildon_button_set_title (HILDON_BUTTON (widgetSize), "Display size");
+	hildon_button_set_title (HILDON_BUTTON (widgetSize), _("Display size"));
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (widgetSize), HILDON_TOUCH_SELECTOR (sizeSelector));
 	gtk_box_pack_start (GTK_BOX (content_area), widgetSize, FALSE, FALSE, 0);
 	
 	GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
 	GtkWidget *singleModeToggle = hildon_gtk_radio_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, NULL);
 	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (singleModeToggle), FALSE);
-	gtk_button_set_label (GTK_BUTTON (singleModeToggle), "Single Photo Mode");
+	gtk_button_set_label (GTK_BUTTON (singleModeToggle), _("Single Photo Mode"));
 	GtkWidget *slideshowModeToggle = hildon_gtk_radio_button_new_from_widget (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, GTK_RADIO_BUTTON (singleModeToggle));
 	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (slideshowModeToggle), FALSE);
-	gtk_button_set_label (GTK_BUTTON (slideshowModeToggle), "Slide Show Mode");
+	gtk_button_set_label (GTK_BUTTON (slideshowModeToggle), _("Slide Show Mode"));
 	gtk_box_pack_start (GTK_BOX (hbox), singleModeToggle, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), slideshowModeToggle, FALSE, FALSE, 0);
 	
 	GtkWidget *singlePhotoButton = hildon_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
-	hildon_button_set_title (HILDON_BUTTON (singlePhotoButton), "Select photo");
+	hildon_button_set_title (HILDON_BUTTON (singlePhotoButton), _("Select photo"));
 	gchar *filename = g_filename_display_basename (self->priv->singleFilename);
 	hildon_button_set_value (HILDON_BUTTON (singlePhotoButton), filename);
 	g_free (filename);
@@ -526,33 +534,33 @@ void personal_photo_frame_settings (HDHomePluginItem *hitem, PersonalPhotoFrame
 	g_signal_connect (singlePhotoButton, "clicked", G_CALLBACK (personal_photo_from_single_photo_select), self);
 	
 	GtkWidget *slideshowDirButton = hildon_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
-	hildon_button_set_title (HILDON_BUTTON (slideshowDirButton), "Select directory");
+	hildon_button_set_title (HILDON_BUTTON (slideshowDirButton), _("Select directory"));
 	hildon_button_set_value (HILDON_BUTTON (slideshowDirButton), self->priv->slideshowDirname);
 	gtk_box_pack_start (GTK_BOX (self->priv->slideshowModeBox), slideshowDirButton, FALSE, FALSE, 0);
 	g_signal_connect (slideshowDirButton, "clicked", G_CALLBACK (personal_photo_frame_slideshow_dir_select), self);
 	
 	GtkWidget *selector = hildon_touch_selector_new_text ();
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "when changing desktops");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 30 seconds");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every minute");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 5 minutes");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 10 minutes");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every 30 minutes");
-	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), "every hour");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("when changing desktops"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 30 seconds"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every minute"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 5 minutes"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 10 minutes"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every 30 minutes"));
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector), _("every hour"));
 	hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, self->priv->slideshowDuration);
 	
 	GtkWidget *slideshowDuration = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_HORIZONTAL);
-	hildon_button_set_title (HILDON_BUTTON (slideshowDuration), "Change photos");
+	hildon_button_set_title (HILDON_BUTTON (slideshowDuration), _("Change photos"));
 	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (slideshowDuration), HILDON_TOUCH_SELECTOR (selector));
 	gtk_box_pack_start (GTK_BOX (self->priv->slideshowModeBox), slideshowDuration, FALSE, FALSE, 0);
 	
 	GtkWidget *slideshowRandom = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (slideshowRandom), "Display in random order");
+	gtk_button_set_label (GTK_BUTTON (slideshowRandom), _("Display in random order"));
 	hildon_check_button_set_active (HILDON_CHECK_BUTTON (slideshowRandom), self->priv->slideshowRandom);
 	//gtk_box_pack_start (GTK_BOX (self->priv->slideshowModeBox), slideshowRandom, FALSE, FALSE, 0);
 	
 	GtkWidget *showSlideshowControls = hildon_check_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-	gtk_button_set_label (GTK_BUTTON (showSlideshowControls), "Display slide show controls");
+	gtk_button_set_label (GTK_BUTTON (showSlideshowControls), _("Display slide show controls"));
 	hildon_check_button_set_active (HILDON_CHECK_BUTTON (showSlideshowControls), self->priv->showSlideshowControls);
 	gtk_box_pack_start (GTK_BOX (self->priv->slideshowModeBox), showSlideshowControls, FALSE, FALSE, 0);
 	
@@ -830,6 +838,10 @@ static void personal_photo_frame_class_finalize (PersonalPhotoFrameClass *klass
 static void personal_photo_frame_init (PersonalPhotoFrame *self)
 {
 	//g_warning("%s", __PRETTY_FUNCTION__);
+	setlocale (LC_ALL, "");
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	textdomain (GETTEXT_PACKAGE);
+
 	self->priv = PERSONAL_PHOTO_FRAME_GET_PRIVATE (self);
 	self->priv->eventID = 0;
 	self->priv->isPressed = FALSE;
